@@ -158,5 +158,10 @@ class Application(Blueprint):
         self.app = self.make_app(**self.kwargs)
         self.server = HTTPServer(self.app, xheaders=xheaders, max_buffer_size=max_buffer_size)
         self.server.add_sockets(sockets)
-        self.logger.info(f"Debug: {self.app.settings['debug']}, Running: http://{get_ip()}:{port}")
+        local_ip = get_ip()
+        remote_ip = get_ip(False)
+        if local_ip == remote_ip:
+            self.logger.info(f"Debug: {self.app.settings['debug']}, Address: http://{local_ip}:{port}")
+        else:
+            self.logger.info(f"Debug: {self.app.settings['debug']}, Local: http://{local_ip}:{port}, Remote: http://{remote_ip}:{port}")
         self.ioloop.start()
