@@ -158,7 +158,7 @@ class SignupHandler(BaseHandler):
                 'token': token,
                 'created_at': datetime.datetime.now().replace(microsecond=0)
             })
-            if doc.id == 1:
+            if doc.get('id') == 1:
                 doc.admin = True
             await awaitable(self.db.users.insert_one(doc))
             self.set_cookie('token', token, expires_days=30)
