@@ -370,13 +370,14 @@ class BaseRequest(metaclass=RequestMeta):
             return self._retry(url, kwargs, retry)
 
     def download(self, url, filename=None, shards=1, **kwargs):
-        url, kwargs = self._prepare(url, kwargs)
-        kwargs['headers']['Range'] = 'bytes=0-0'
-        resp = self._request(url, **kwargs)
-        filesize = int(resp.headers['Content-Range'].split('/')[-1])
-        filename = filename or url.split('/')[-1]
-        lock = threading.Lock()
+        filename = Path(filename or Path(url).name)
         if shards > 1:
+            url, kwargs = self._prepare(url, kwargs)
+            kwargs['headers']['Range'] = 'bytes=0-0'
+            resp = self._request(url, **kwargs)
+            filesize = int(resp.headers['Content-Range'].split('/')[-1])
+            lock = threading.Lock()
+            filename.parent.mkdir(parents=True, exist_ok=True)
             with open(filename, 'wb') as fp:
                 fp.truncate(filesize)
             fp = open(filename, 'rb+')
@@ -386,14 +387,12 @@ class BaseRequest(metaclass=RequestMeta):
             func = partial(self._download, url, kwargs, fp, lock)
             with ThreadPoolExecutor(shards) as executor:
                 executor.map(func, *args)
+            fp.close()
         else:
-            start = os.path.getsize(filename) if os.path.exists(filename) else 0
-            end = filesize - 1
-            fp = open(filename, 'ab')
-            if start < end:
-                kwargs['headers']['Range'] = f'bytes={start}-{end}'
-                self._download(url, kwargs, fp, lock, start, end)
-        fp.close()
+            resp = self._request(url, **kwargs)
+            if resp.code == 200:
+                filename.parent.mkdir(parents=True, exist_ok=True)
+                filename.write_bytes(resp.body)
 
     def get(self, url, **kwargs):
         return self.request(url, method='get', **kwargs)
@@ -804,7 +803,7 @@ class TornadoClient(Pycurl):
         return resp
 
     async def download(self, url, filename=None, shards=1, **kwargs):
-        filename = filename or Path(url).name
+        filename = Path(filename or Path(url).name)
         if shards > 1:
             url, kwargs = self._prepare(url, kwargs)
             kwargs['headers']['Range'] = 'bytes=0-0'
@@ -819,13 +818,16 @@ class TornadoClient(Pycurl):
                 _kwargs['headers']['Range'] = f'bytes={start}-{end}'
                 futures.append(self._request(url, **_kwargs))
             resps = await asyncio.gather(*futures)
+            filename.parent.mkdir(parents=True, exist_ok=True)
             with open(filename, 'wb') as fp:
                 for resp in resps:
-                    fp.write(resp.body)
+                    if resp.code == 206:
+                        fp.write(resp.body)
         else:
             resp = await self._request(url, **kwargs)
-            with open(filename, 'wb') as fp:
-                fp.write(resp.body)
+            if resp.code == 200:
+                filename.parent.mkdir(parents=True, exist_ok=True)
+                filename.write_bytes(resp.body)
 
 
 class Fetcher(BaseRequest):
